==> apache-tomcat-8.5.71-src.zip: apache-tomcat-8.5.71-src/java/org/apache/catalina/core/ApplicationMappingImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.catalina.core;

public class ApplicationMappingImpl {

    private final String matchValue;
    private final String pattern;
    private final ApplicationMappingMatch mappingType;
    private final String servletName;

    public ApplicationMappingImpl(String matchValue, String pattern, ApplicationMappingMatch mappingType, String servletName) {
        this.matchValue = matchValue;
        this.pattern = pattern;
        this.mappingType = mappingType;
        this.servletName = servletName;
    }


    public String getMatchValue() {
        return matchValue;
    }


    public String getPattern() {
        return pattern;
    }


    public ApplicationMappingMatch getMappingMatch() {
        return mappingType;
    }


    public String getServletName() {
        return servletName;
    }
}

==> apache-tomcat-8.5.87-src.zip: apache-tomcat-8.5.87-src/java/org/apache/catalina/core/ApplicationMappingImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.catalina.core;

public class ApplicationMappingImpl {

    private final String matchValue;
    private final String pattern;
    private final ApplicationMappingMatch mappingType;
    private final String servletName;

    public ApplicationMappingImpl(String matchValue, String pattern, ApplicationMappingMatch mappingType,
            String servletName) {
        this.matchValue = matchValue;
        this.pattern = pattern;
        this.mappingType = mappingType;
        this.servletName = servletName;
    }


    public String getMatchValue() {
        return matchValue;
    }


    public String getPattern() {
        return pattern;
    }


    public ApplicationMappingMatch getMappingMatch() {
        return mappingType;
    }


    public String getServletName() {
        return servletName;
    }
}
